@@ -59,6 +59,7 @@ class Api:
         self.audit = api_client("audit")
         self.sui_layouts = api_client("sui/layout")
         self.sui_product = api_client("sui/product")
+        self.sui_coupon = api_client("sui/coupon")
         self.sui_network = api_client("sui/network")
         self.signup = api_client("signup")
         self.ad_units = api_client("adunits")
@@ -90,6 +91,7 @@ class Api:
         self.field_mappings = api_client("fieldmappings")
         self.folders = api_client("folders")
         self.impact_report = api_client("impactreport")
+        self.invoice_translations = api_client("invoicetranslations")
         self.key_values = api_client("keyvalues")
         self.key_values_upload = api_client("keyvalues/upload")
         self.keywords = api_client("keywords")
@@ -162,11 +164,12 @@ class ApiClient:
         else:
             self.session = session
 
-    def get(self, object_id, sub_resource=None, args=None):
+    def get(self, object_id, args=None, sub_resource=None):
         """
         Perform a GET request for the supplied object id.
         :param object_id:    object id used to construct the url
-        :param args:        optional dictionary of query parameters
+        :param args:         optional dictionary of query parameters
+        :param sub_resource: optional sub resource
         :return:            dictionary of the JSON object returned
         """
         if args is None:
@@ -214,35 +217,18 @@ class ApiClient:
             raise re
 
     def copy(self, object_id, data=None, args=None):
-        """
-        Perform a copy request for the supplied object id.
-        :param object_id:    object id used to construct the url
-        :param data:        optional dictionary of form parameters
-        :param args        optional dictionary of query parameters
-        :return:            dictionary of the JSON object returned
-        """
-        if data is None:
-            data = {}
-        if args is None:
-            args = {}
-        headers = self.auth()
-        headers['Accept-Encoding'] = 'gzip'
-        headers.update(self.api.headers)
+        return self.post(object_id=object_id, data=data, args=args, sub_resource='copy')
 
-        url = self.baseUrl + self.version + "/" + self.resourceName + "/" + object_id + "/copy"
-        r = self.handle_err(self.session.post(url, headers=headers, data=data,
-                                              params=dict(list(self.api.defaultArgs.items()) + list(args.items()))))
-        if r.text == '':
-            return None
-        else:
-            return r.json()
+    def defaults(self):
+        return self.query(sub_resource='defaults')
 
-    def post(self, object_id=None, sub_resource=None, data=None, args=None):
+    def post(self, object_id=None, data=None, args=None, sub_resource=None):
         """
         Perform a POST request for the supplied object id.
         :param object_id:    object id used to construct the url
-        :param data:        optional dictionary of form parameters
-        :param args        optional dictionary of query parameters
+        :param data:         optional dictionary of form parameters
+        :param args          optional dictionary of query parameters
+        :param sub_resource: optional sub resource
         :return:            dictionary of the JSON object returned
         """
         if data is None:
@@ -266,7 +252,7 @@ class ApiClient:
         else:
             return r.json()
 
-    def query(self, args=None):
+    def query(self, args=None, sub_resource=None):
         """
         Perform a query (a GET from an endpoint without a specific object ID).
         :param args:        optional dictionary of query parameters
@@ -277,7 +263,12 @@ class ApiClient:
         headers = self.auth()
         headers['Accept-Encoding'] = 'gzip'
         headers.update(self.api.headers)
-        r = self.handle_err(self.session.get(self.baseUrl + self.version + "/" + self.resourceName,
+
+        url = self.baseUrl + self.version + "/" + self.resourceName
+        if sub_resource:
+            url += "/" + sub_resource
+
+        r = self.handle_err(self.session.get(url,
                                              headers=headers,
                                              params=dict(list(self.api.defaultArgs.items()) + list(args.items()))))
         if r.text == '':
@@ -285,7 +276,7 @@ class ApiClient:
         else:
             return r.json()
 
-    def run(self, data, args=None):
+    def run(self, data, args=None, sub_resource=None):
         """
         Perform a query requiring a request body to be sent (i.e. requires POST rather than GET).
         :param data:        dictionary to be converted to json to post
@@ -300,8 +291,11 @@ class ApiClient:
         headers.update(self.api.headers)
 
         params = dict(list(self.api.defaultArgs.items()) + list(args.items()))
+        url = self.baseUrl + self.version + "/" + self.resourceName
+        if sub_resource:
+            url += "/" + sub_resource
 
-        r = self.handle_err(self.session.post(self.baseUrl + self.version + "/" + self.resourceName,
+        r = self.handle_err(self.session.post(url,
                                               headers=headers,
                                               data=json.dumps(data),
                                               params=params))
